==> charlatan_0.4.0.tar.gz: charlatan/R/person-provider-no_NO.R <==
# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/person/no_NO/__init__.py

person_formats_no_no = c(
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{first_names_male1}}-{{first_names_male2}} {{last_names}}',
  '{{first_names_male1}}-{{first_names_male2}} {{last_names}}',
  '{{first_names_female1}}-{{first_names_female2}} {{last_names}}',
  '{{first_names_female1}}-{{first_names_female2}} {{last_names}}',
  '{{first_names}} {{last_names1}}-{{last_names2}}',
  '{{first_names}} {{last_names1}}-{{last_names2}}',
  '{{prefixes}} {{first_names_male}} {{last_names}}'
)

# 100 most common male first names, alphabetically.
# Source: http://www.ssb.no/a/navn/fornavn-menn-100.html
person_first_names_male_no_no = c(
  "Adrian",
  "Alexander",
  "Alf",
  "Anders",
  "Andreas",
  "Arild",
  "Arne",
  "Asbj\u00f8rn",
  "Bj\u00f8rn",
  "Christian",
  "Dag",
  "Daniel",
  "Egil",
  "Einar",
  "Eirik",
  "Eivind",
  "Emil",
  "Erik",
  "Erling",
  "Espen",
  "Finn",
  "Frank",
  "Fredrik",
  "Frode",
  "Geir",
  "Gunnar",
  "Hans",
  "Harald",
  "Helge",
  "Henrik",
  "H\u00e5kon",
  "H\u00e5vard",
  "Ivar",
  "Jan",
  "Jens",
  "Joakim",
  "Johannes",
  "Johan",
  "John",
  "Jonas",
  "Jon",
  "J\u00f8rgen",
  "Karl",
  "Kenneth",
  "Kim",
  "Kjell",
  "Kjetil",
  "Knut",
  "K\u00e5re",
  "Kristian",
  "Kristoffer",
  "Lars",
  "Leif",
  "Magne",
  "Magnus",
  "Marius",
  "Markus",
  "Martin",
  "Mathias",
  "Morten",
  "Nils",
  "Odd",
  "Ola",
  "Olav",
  "Ole",
  "Per",
  "Petter",
  "P\u00e5l",
  "Roar",
  "Robert",
  "Roger",
  "Rolf",
  "Roy",
  "Rune",
  "Sander",
  "Sebastian",
  "Sigurd",
  "Simen",
  "Sindre",
  "Sondre",
  "Steinar",
  "Stein",
  "Stian",
  "Stig",
  "Svein",
  "Sverre",
  "Terje",
  "Thomas",
  "Thor",
  "Tobias",
  "Tommy",
  "Tom",
  "Torbj\u00f8rn",
  "Tore",
  "Tor",
  "Trond",
  "Vegard",
  "Vidar",
  "\u00d8ystein",
  "\u00d8yvind"
)

# 100 most common female first names, alphabetically.
# Source: http://www.ssb.no/a/navn/fornavn-kvinner-100.html
person_first_names_female_no_no = c(
  "Andrea",
  "Anette",
  "Anita",
  "Anna",
  "Anne",
  "Ann",
  "Astrid",
  "Aud",
  "Bente",
  "Berit",
  "Bj\u00f8rg",
  "Britt",
  "Camilla",
  "Cathrine",
  "Cecilie",
  "Elin",
  "Elisabeth",
  "Elise",
  "Eli",
  "Ellen",
  "Else",
  "Emilie",
  "Emma",
  "Eva",
  "Gerd",
  "Grete",
  "Grethe",
  "Gro",
  "Gunn",
  "Hanna",
  "Hanne",
  "Hege",
  "Heidi",
  "Helene",
  "Hilde",
  "Ida",
  "Ingeborg",
  "Inger",
  "Ingrid",
  "Irene",
  "Janne",
  "Jenny",
  "Jorunn",
  "Julie",
  "Karen",
  "Karin",
  "Kari",
  "Karoline",
  "Kirsten",
  "Kjersti",
  "Kristine",
  "Kristin",
  "Laila",
  "Lene",
  "Linda",
  "Line",
  "Linn",
  "Lise",
  "Liv",
  "Malin",
  "Maren",
  "Marianne",
  "Maria",
  "Marie",
  "Mari",
  "Marit",
  "Marte",
  "Martine",
  "May",
  "Mette",
  "Mona",
  "Monica",
  "Nina",
  "Nora",
  "Ragnhild",
  "Randi",
  "Reidun",
  "Rita",
  "Ruth",
  "Sara",
  "Sigrid",
  "Silje",
  "Siri",
  "Sissel",
  "Siv",
  "Sofie",
  "Solveig",
  "Stine",
  "Synn\u00f8ve",
  "Thea",
  "Tone",
  "Tonje",
  "Torill",
  "Tove",
  "Trine",
  "Turid",
  "Unni",
  "Vilde",
  "Wenche",
  "\u00c5se"
)

person_first_names_no_no = c(person_first_names_male_no_no,
                             person_first_names_female_no_no)

# 100 most common last names, alphabetically.
# Source: http://www.ssb.no/a/navn/alf/etter100.html
person_last_names_no_no = c(
  "Aasen",
  "Aas",
  "Abrahamsen",
  "Ahmed",
  "Ali",
  "Amundsen",
  "Andersen",
  "Andreassen",
  "Andresen",
  "Antonsen",
  "Arnesen",
  "Aune",
  "Bakken",
  "Bakke",
  "Berge",
  "Berg",
  "Berntsen",
  "B\u00f8e",
  "Birkeland",
  "Brekke",
  "Christensen",
  "Dahl",
  "Danielsen",
  "\u00f8deg\u00e5rd",
  "Edvardsen",
  "Eide",
  "Eliassen",
  "Ellingsen",
  "Engen",
  "Eriksen",
  "Evensen",
  "Fredriksen",
  "Gulbrandsen",
  "Gundersen",
  "Hagen",
  "Halvorsen",
  "Hansen",
  "Hanssen",
  "Haugen",
  "Hauge",
  "Haugland",
  "Haug",
  "Helland",
  "Henriksen",
  "Holm",
  "Isaksen",
  "Iversen",
  "Jacobsen",
  "Jakobsen",
  "Jensen",
  "Jenssen",
  "Johannessen",
  "Johansen",
  "Johnsen",
  "J\u00f8rgensen",
  "Karlsen",
  "Knudsen",
  "Knutsen",
  "Kristensen",
  "Kristiansen",
  "Kristoffersen",
  "Larsen",
  "Lien",
  "Lie",
  "Lunde",
  "Lund",
  "Madsen",
  "Martinsen",
  "Mathisen",
  "Mikkelsen",
  "Moen",
  "Moe",
  "Myhre",
  "Myklebust",
  "Nguyen",
  "Nielsen",
  "Nilsen",
  "N\u00e6ss",
  "Nyg\u00e5rd",
  "Olsen",
  "Paulsen",
  "Pedersen",
  "Pettersen",
  "Rasmussen",
  "R\u00f8nning",
  "Ruud",
  "Sandvik",
  "Simonsen",
  "Sivertsen",
  "Solberg",
  "Solheim",
  "S\u00f8rensen",
  "S\u00e6ther",
  "Strand",
  "Str\u00f8m",
  "Svendsen",
  "Tangen",
  "Thomassen",
  "Thorsen",
  "Tveit",
  "Vik"
)

person_prefixes_no_no = c('Dr.', 'Prof.')

person_no_no <- list(
  first_names = person_first_names_no_no,
  first_names_female = person_first_names_female_no_no,
  first_names_male = person_first_names_male_no_no,
  last_names = person_last_names_no_no,
  prefixes = person_prefixes_no_no
)

==> charlatan_0.5.1.tar.gz: charlatan/R/person-provider-no_NO.R <==
# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/person/no_NO/__init__.py

person_formats_no_no <- c(
  "{{first_names}} {{last_names}}",
  "{{first_names}} {{last_names}}",
  "{{first_names}} {{last_names}}",
  "{{first_names}} {{last_names}}",
  "{{first_names}} {{last_names}}",
  "{{first_names}} {{last_names}}",
  "{{first_names}} {{last_names}}",
  "{{first_names}} {{last_names}}",
  "{{first_names}} {{last_names}}",
  "{{first_names}} {{last_names}}",
  "{{first_names}} {{last_names}}",
  "{{first_names}} {{last_names}}",
  "{{first_names}} {{last_names}}",
  "{{first_names}} {{last_names}}",
  "{{first_names}} {{last_names}}",
  "{{first_names}} {{last_names}}",
  "{{first_names_male1}}-{{first_names_male2}} {{last_names}}",
  "{{first_names_male1}}-{{first_names_male2}} {{last_names}}",
  "{{first_names_female1}}-{{first_names_female2}} {{last_names}}",
  "{{first_names_female1}}-{{first_names_female2}} {{last_names}}",
  "{{first_names}} {{last_names1}}-{{last_names2}}",
  "{{first_names}} {{last_names1}}-{{last_names2}}",
  "{{prefixes}} {{first_names_male}} {{last_names}}"
)

# 100 most common male first names, alphabetically.
# Source: http://www.ssb.no/a/navn/fornavn-menn-100.html
person_first_names_male_no_no <- c(
  "Adrian",
  "Alexander",
  "Alf",
  "Anders",
  "Andreas",
  "Arild",
  "Arne",
  "Asbj\u00f8rn",
  "Bj\u00f8rn",
  "Christian",
  "Dag",
  "Daniel",
  "Egil",
  "Einar",
  "Eirik",
  "Eivind",
  "Emil",
  "Erik",
  "Erling",
  "Espen",
  "Finn",
  "Frank",
  "Fredrik",
  "Frode",
  "Geir",
  "Gunnar",
  "Hans",
  "Harald",
  "Helge",
  "Henrik",
  "H\u00e5kon",
  "H\u00e5vard",
  "Ivar",
  "Jan",
  "Jens",
  "Joakim",
  "Johannes",
  "Johan",
  "John",
  "Jonas",
  "Jon",
  "J\u00f8rgen",
  "Karl",
  "Kenneth",
  "Kim",
  "Kjell",
  "Kjetil",
  "Knut",
  "K\u00e5re",
  "Kristian",
  "Kristoffer",
  "Lars",
  "Leif",
  "Magne",
  "Magnus",
  "Marius",
  "Markus",
  "Martin",
  "Mathias",
  "Morten",
  "Nils",
  "Odd",
  "Ola",
  "Olav",
  "Ole",
  "Per",
  "Petter",
  "P\u00e5l",
  "Roar",
  "Robert",
  "Roger",
  "Rolf",
  "Roy",
  "Rune",
  "Sander",
  "Sebastian",
  "Sigurd",
  "Simen",
  "Sindre",
  "Sondre",
  "Steinar",
  "Stein",
  "Stian",
  "Stig",
  "Svein",
  "Sverre",
  "Terje",
  "Thomas",
  "Thor",
  "Tobias",
  "Tommy",
  "Tom",
  "Torbj\u00f8rn",
  "Tore",
  "Tor",
  "Trond",
  "Vegard",
  "Vidar",
  "\u00d8ystein",
  "\u00d8yvind"
)

# 100 most common female first names, alphabetically.
# Source: http://www.ssb.no/a/navn/fornavn-kvinner-100.html
person_first_names_female_no_no <- c(
  "Andrea",
  "Anette",
  "Anita",
  "Anna",
  "Anne",
  "Ann",
  "Astrid",
  "Aud",
  "Bente",
  "Berit",
  "Bj\u00f8rg",
  "Britt",
  "Camilla",
  "Cathrine",
  "Cecilie",
  "Elin",
  "Elisabeth",
  "Elise",
  "Eli",
  "Ellen",
  "Else",
  "Emilie",
  "Emma",
  "Eva",
  "Gerd",
  "Grete",
  "Grethe",
  "Gro",
  "Gunn",
  "Hanna",
  "Hanne",
  "Hege",
  "Heidi",
  "Helene",
  "Hilde",
  "Ida",
  "Ingeborg",
  "Inger",
  "Ingrid",
  "Irene",
  "Janne",
  "Jenny",
  "Jorunn",
  "Julie",
  "Karen",
  "Karin",
  "Kari",
  "Karoline",
  "Kirsten",
  "Kjersti",
  "Kristine",
  "Kristin",
  "Laila",
  "Lene",
  "Linda",
  "Line",
  "Linn",
  "Lise",
  "Liv",
  "Malin",
  "Maren",
  "Marianne",
  "Maria",
  "Marie",
  "Mari",
  "Marit",
  "Marte",
  "Martine",
  "May",
  "Mette",
  "Mona",
  "Monica",
  "Nina",
  "Nora",
  "Ragnhild",
  "Randi",
  "Reidun",
  "Rita",
  "Ruth",
  "Sara",
  "Sigrid",
  "Silje",
  "Siri",
  "Sissel",
  "Siv",
  "Sofie",
  "Solveig",
  "Stine",
  "Synn\u00f8ve",
  "Thea",
  "Tone",
  "Tonje",
  "Torill",
  "Tove",
  "Trine",
  "Turid",
  "Unni",
  "Vilde",
  "Wenche",
  "\u00c5se"
)

person_first_names_no_no <- c(
  person_first_names_male_no_no,
  person_first_names_female_no_no
)

# 100 most common last names, alphabetically.
# Source: http://www.ssb.no/a/navn/alf/etter100.html
person_last_names_no_no <- c(
  "Aasen",
  "Aas",
  "Abrahamsen",
  "Ahmed",
  "Ali",
  "Amundsen",
  "Andersen",
  "Andreassen",
  "Andresen",
  "Antonsen",
  "Arnesen",
  "Aune",
  "Bakken",
  "Bakke",
  "Berge",
  "Berg",
  "Berntsen",
  "B\u00f8e",
  "Birkeland",
  "Brekke",
  "Christensen",
  "Dahl",
  "Danielsen",
  "\u00f8deg\u00e5rd",
  "Edvardsen",
  "Eide",
  "Eliassen",
  "Ellingsen",
  "Engen",
  "Eriksen",
  "Evensen",
  "Fredriksen",
  "Gulbrandsen",
  "Gundersen",
  "Hagen",
  "Halvorsen",
  "Hansen",
  "Hanssen",
  "Haugen",
  "Hauge",
  "Haugland",
  "Haug",
  "Helland",
  "Henriksen",
  "Holm",
  "Isaksen",
  "Iversen",
  "Jacobsen",
  "Jakobsen",
  "Jensen",
  "Jenssen",
  "Johannessen",
  "Johansen",
  "Johnsen",
  "J\u00f8rgensen",
  "Karlsen",
  "Knudsen",
  "Knutsen",
  "Kristensen",
  "Kristiansen",
  "Kristoffersen",
  "Larsen",
  "Lien",
  "Lie",
  "Lunde",
  "Lund",
  "Madsen",
  "Martinsen",
  "Mathisen",
  "Mikkelsen",
  "Moen",
  "Moe",
  "Myhre",
  "Myklebust",
  "Nguyen",
  "Nielsen",
  "Nilsen",
  "N\u00e6ss",
  "Nyg\u00e5rd",
  "Olsen",
  "Paulsen",
  "Pedersen",
  "Pettersen",
  "Rasmussen",
  "R\u00f8nning",
  "Ruud",
  "Sandvik",
  "Simonsen",
  "Sivertsen",
  "Solberg",
  "Solheim",
  "S\u00f8rensen",
  "S\u00e6ther",
  "Strand",
  "Str\u00f8m",
  "Svendsen",
  "Tangen",
  "Thomassen",
  "Thorsen",
  "Tveit",
  "Vik"
)

person_prefixes_no_no <- c("Dr.", "Prof.")

person_no_no <- list(
  first_names = person_first_names_no_no,
  first_names_female = person_first_names_female_no_no,
  first_names_male = person_first_names_male_no_no,
  last_names = person_last_names_no_no,
  prefixes = person_prefixes_no_no
)
